@@ -27,14 +27,14 @@
 #include "disk-io.h"
 #include "print-tree.h"
 #include "transaction.h"
-#include "list.h"
-#include "utils.h"
-#include "help.h"
+#include "kernel-lib/list.h"
+#include "common/utils.h"
+#include "common/help.h"
 
 static void print_usage(void)
 {
 	printf("usage: btrfs-select-super -s number dev\n");
-	printf("\t-s super   copy of superbloc to overwrite the primary one (values: 1, 2)\n");
+	printf("\t-s super   copy of superblock to overwrite the primary one (values: 1, 2)\n");
 	exit(1);
 }
 
@@ -67,7 +67,7 @@ int main(int argc, char **argv)
 	}
 	set_argv0(argv);
 	if (check_argc_exact(argc - optind, 1))
-		print_usage();
+		return 1;
 
 	if (bytenr == 0) {
 		fprintf(stderr, "Please select the super copy with -s\n");
